@@ -17,21 +17,11 @@ using namespace KAddressBook;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMKaddressbookPluginsConfig, "kaddressbook_config_plugins.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMKaddressbookPluginsConfig::KCMKaddressbookPluginsConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , mConfigurePluginWidget(new PimCommon::ConfigurePluginsWidget(new KAddressBookConfigPluginListWidget(this), this))
-#else
-KCMKaddressbookPluginsConfig::KCMKaddressbookPluginsConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KCMKaddressbookPluginsConfig::KCMKaddressbookPluginsConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , mConfigurePluginWidget(new PimCommon::ConfigurePluginsWidget(new KAddressBookConfigPluginListWidget(widget()), widget()))
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QHBoxLayout(this);
-#else
     auto lay = new QHBoxLayout(widget());
-#endif
     lay->setContentsMargins({});
     connect(mConfigurePluginWidget, &PimCommon::ConfigurePluginsWidget::changed, this, &KCMKaddressbookPluginsConfig::slotConfigChanged);
     lay->addWidget(mConfigurePluginWidget);
@@ -39,11 +29,7 @@ KCMKaddressbookPluginsConfig::KCMKaddressbookPluginsConfig(QObject *parent, cons
 
 void KCMKaddressbookPluginsConfig::slotConfigChanged()
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     markAsChanged();
-#endif
 }
 
 void KCMKaddressbookPluginsConfig::save()
@@ -62,3 +48,5 @@ void KCMKaddressbookPluginsConfig::defaults()
 }
 
 #include "kaddressbook_config_plugins.moc"
+
+#include "moc_kaddressbook_config_plugins.cpp"
