@@ -11,32 +11,18 @@
 #include <QHBoxLayout>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/FeedbackConfigWidget>
-#else
-#include <KUserFeedback/FeedbackConfigWidget>
-#endif
 #endif
 
 using namespace KAddressBook;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMKaddressbookUserFeedBackConfig, "kaddressbook_config_userfeedback.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMKaddressbookUserFeedBackConfig::KCMKaddressbookUserFeedBackConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , mUserFeedbackWidget(new KUserFeedback::FeedbackConfigWidget(this))
-#else
-KCMKaddressbookUserFeedBackConfig::KCMKaddressbookUserFeedBackConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KCMKaddressbookUserFeedBackConfig::KCMKaddressbookUserFeedBackConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , mUserFeedbackWidget(new KUserFeedback::FeedbackConfigWidget(widget()))
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QHBoxLayout(this);
-#else
     auto lay = new QHBoxLayout(widget());
-#endif
     lay->setContentsMargins({});
     connect(mUserFeedbackWidget, &KUserFeedback::FeedbackConfigWidget::configurationChanged, this, &KCMKaddressbookUserFeedBackConfig::markAsChanged);
 
@@ -62,3 +48,5 @@ void KCMKaddressbookUserFeedBackConfig::defaults()
 }
 
 #include "kaddressbook_config_userfeedback.moc"
+
+#include "moc_kaddressbook_config_userfeedback.cpp"
