@@ -65,6 +65,7 @@
 #include <KActionMenu>
 #include <KCMultiDialog>
 #include <KCheckableProxyModel>
+#include <KColorSchemeMenu>
 #include <KContacts/ContactGroup>
 #include <KDescendantsProxyModel>
 #include <KLocalizedString>
@@ -114,7 +115,7 @@ public:
     {
     }
 
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override
     {
         if (!index.isValid()) {
             return {};
@@ -253,7 +254,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     mItemView->setRootIsDecorated(false);
     mItemView->header()->setDefaultAlignment(Qt::AlignCenter);
 
-    mActionManager = new ContactEditor::StandardContactActionManager(guiClient->actionCollection(), this);
+    mActionManager = new Akonadi::StandardContactActionManager(guiClient->actionCollection(), this);
     mActionManager->setCollectionSelectionModel(mCollectionView->selectionModel());
     mActionManager->setItemSelectionModel(mItemView->selectionModel());
 
@@ -270,11 +271,11 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
         mActionManager->createAction(standardAction);
     }
     guiClient->actionCollection()->setDefaultShortcut(mActionManager->action(Akonadi::StandardActionManager::DeleteItems), QKeySequence(Qt::Key_Delete));
-    QList<ContactEditor::StandardContactActionManager::Type> contactActions;
-    contactActions << ContactEditor::StandardContactActionManager::CreateContact << ContactEditor::StandardContactActionManager::CreateContactGroup
-                   << ContactEditor::StandardContactActionManager::EditItem;
+    QList<Akonadi::StandardContactActionManager::Type> contactActions;
+    contactActions << Akonadi::StandardContactActionManager::CreateContact << Akonadi::StandardContactActionManager::CreateContactGroup
+                   << Akonadi::StandardContactActionManager::EditItem;
 
-    for (ContactEditor::StandardContactActionManager::Type contactAction : std::as_const(contactActions)) {
+    for (Akonadi::StandardContactActionManager::Type contactAction : std::as_const(contactActions)) {
         mActionManager->createAction(contactAction);
     }
 
@@ -287,7 +288,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     connect(mItemView, qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::currentChanged), this, &MainWidget::itemSelected);
     connect(mItemView,
             qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::doubleClicked),
-            mActionManager->action(ContactEditor::StandardContactActionManager::EditItem),
+            mActionManager->action(Akonadi::StandardContactActionManager::EditItem),
             &QAction::trigger);
     connect(mItemView->selectionModel(), &QItemSelectionModel::currentChanged, this, &MainWidget::itemSelectionChanged);
 
@@ -305,9 +306,6 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     initializeImportExportPlugin(guiClient->actionCollection());
     QMetaObject::invokeMethod(this, &MainWidget::delayedInit, Qt::QueuedConnection);
     updateQuickSearchText();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(qApp, &QApplication::paletteChanged, this, &MainWidget::slotGeneralPaletteChanged);
-#endif
 }
 
 void MainWidget::slotGeneralPaletteChanged()
@@ -318,11 +316,9 @@ void MainWidget::slotGeneralPaletteChanged()
 
 bool MainWidget::event(QEvent *e)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (e->type() == QEvent::ApplicationPaletteChange) {
         slotGeneralPaletteChanged();
     }
-#endif
     return QWidget::event(e);
 }
 
@@ -333,7 +329,7 @@ void MainWidget::setFocusToTreeView()
 
 void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 {
-    const QVector<KAddressBookImportExport::Plugin *> listPlugins = KAddressBookImportExport::PluginManager::self()->pluginsList();
+    const QList<KAddressBookImportExport::Plugin *> listPlugins = KAddressBookImportExport::PluginManager::self()->pluginsList();
     QList<QAction *> importActions;
     QList<QAction *> exportActions;
     for (KAddressBookImportExport::Plugin *plugin : listPlugins) {
@@ -367,14 +363,12 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 
 void MainWidget::configure()
 {
-    QPointer<KCMultiDialog> dlg = new KCMultiDialog(this);
-    const QVector<KPluginMetaData> availablePlugins =
-        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/kaddressbook"));
+    KCMultiDialog dlg(this);
+    const QList<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim6/kcms/kaddressbook"));
     for (const KPluginMetaData &metaData : availablePlugins) {
-        dlg->addModule(metaData);
+        dlg.addModule(metaData);
     }
-    dlg->exec();
-    delete dlg;
+    dlg.exec();
 }
 
 void MainWidget::handleCommandLine(const QStringList &arguments)
@@ -411,7 +405,7 @@ void MainWidget::delayedInit()
 {
     setViewMode(0); // get default from settings
 
-    const KConfigGroup group(Settings::self()->config(), "UiState_ContactView");
+    const KConfigGroup group(Settings::self()->config(), QStringLiteral("UiState_ContactView"));
     KAddressBook::UiStateSaver::restoreState(mItemView, group);
 
     mXmlGuiClient->actionCollection()->action(QStringLiteral("options_show_qrcodes"))->setChecked(showQRCodes());
@@ -430,7 +424,7 @@ MainWidget::~MainWidget()
     mModelColumnManager->store();
     saveSplitterStates();
 
-    KConfigGroup group(Settings::self()->config(), "UiState_ContactView");
+    KConfigGroup group(Settings::self()->config(), QStringLiteral("UiState_ContactView"));
     KAddressBook::UiStateSaver::saveState(mItemView, group);
 
     saveState();
@@ -448,7 +442,7 @@ void MainWidget::restoreState()
         auto saver = new Akonadi::ETMViewStateSaver;
         saver->setView(mCollectionView);
 
-        const KConfigGroup group(Settings::self()->config(), "CollectionViewState");
+        const KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewState"));
         saver->restoreState(group);
     }
 
@@ -457,7 +451,7 @@ void MainWidget::restoreState()
         auto saver = new Akonadi::ETMViewStateSaver;
         saver->setSelectionModel(mCollectionSelectionModel);
 
-        const KConfigGroup group(Settings::self()->config(), "CollectionViewCheckState");
+        const KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewCheckState"));
         saver->restoreState(group);
     }
 
@@ -472,7 +466,7 @@ void MainWidget::restoreState()
             saver->setCurrentItem(mPendingSelection);
             mPendingSelection = {};
         } else {
-            const KConfigGroup group(Settings::self()->config(), "ItemViewState");
+            const KConfigGroup group(Settings::self()->config(), QStringLiteral("ItemViewState"));
             saver->restoreState(group);
         }
     }
@@ -485,7 +479,7 @@ void MainWidget::saveState()
         Akonadi::ETMViewStateSaver saver;
         saver.setView(mCollectionView);
 
-        KConfigGroup group(Settings::self()->config(), "CollectionViewState");
+        KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewState"));
         saver.saveState(group);
         group.sync();
     }
@@ -495,7 +489,7 @@ void MainWidget::saveState()
         Akonadi::ETMViewStateSaver saver;
         saver.setSelectionModel(mCollectionSelectionModel);
 
-        KConfigGroup group(Settings::self()->config(), "CollectionViewCheckState");
+        KConfigGroup group(Settings::self()->config(), QStringLiteral("CollectionViewCheckState"));
         saver.saveState(group);
         group.sync();
     }
@@ -506,7 +500,7 @@ void MainWidget::saveState()
         saver.setView(mItemView);
         saver.setSelectionModel(mItemView->selectionModel());
 
-        KConfigGroup group(Settings::self()->config(), "ItemViewState");
+        KConfigGroup group(Settings::self()->config(), QStringLiteral("ItemViewState"));
         saver.saveState(group);
         group.sync();
     }
@@ -564,15 +558,15 @@ void MainWidget::setupGui()
     detailsPaneLayout->addWidget(mDetailsViewStack);
 
     // the details widget for contacts
-    mContactDetails = new ContactEditor::ContactViewer(mDetailsViewStack);
-    connect(mContactDetails, &ContactEditor::ContactViewer::urlClicked, this, [](const QUrl &url) {
+    mContactDetails = new Akonadi::ContactViewer(mDetailsViewStack);
+    connect(mContactDetails, &Akonadi::ContactViewer::urlClicked, this, [](const QUrl &url) {
         QDesktopServices::openUrl(url);
     });
     mDetailsViewStack->addWidget(mContactDetails);
 
     // the details widget for contact groups
-    mContactGroupDetails = new ContactEditor::ContactGroupViewer(mDetailsViewStack);
-    connect(mContactGroupDetails, &ContactEditor::ContactGroupViewer::urlClicked, this, [](const QUrl &url) {
+    mContactGroupDetails = new Akonadi::ContactGroupViewer(mDetailsViewStack);
+    connect(mContactGroupDetails, &Akonadi::ContactGroupViewer::urlClicked, this, [](const QUrl &url) {
         QDesktopServices::openUrl(url);
     });
     mDetailsViewStack->addWidget(mContactGroupDetails);
@@ -626,6 +620,7 @@ void MainWidget::setupActions(KActionCollection *collection)
                                                             QStringLiteral("theme.desktop"),
                                                             collection,
                                                             QStringLiteral("kaddressbook/viewertemplates/"),
+                                                            QString(),
                                                             this);
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::grantleeThemeSelected, this, &MainWidget::slotGrantleeThemeSelected);
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::updateThemes, this, &MainWidget::slotGrantleeThemesUpdated);
@@ -704,7 +699,7 @@ void MainWidget::setupActions(KActionCollection *collection)
     connect(mServerSideSubscription, &QAction::triggered, this, &MainWidget::slotServerSideSubscription);
 
     auto manager = new KColorSchemeManager(this);
-    collection->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+    collection->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 }
 
 void MainWidget::printPreview()
@@ -716,7 +711,7 @@ void MainWidget::printPreview()
     printer.setCollateCopies(true);
 
     QPointer<QPrintPreviewDialog> previewdlg = new QPrintPreviewDialog(&printer, this);
-    new KWindowStateSaver(previewdlg.data(), "KAddressBookPrintPreviewDialog");
+    new KWindowStateSaver(previewdlg.data(), QLatin1String("KAddressBookPrintPreviewDialog"));
 
     KABPrinting::PrintingWizard wizard(&printer, mItemView->selectionModel(), this);
     wizard.setDefaultAddressBook(currentAddressBook());
@@ -760,12 +755,12 @@ void MainWidget::print()
 
 void MainWidget::newContact()
 {
-    mActionManager->action(ContactEditor::StandardContactActionManager::CreateContact)->trigger();
+    mActionManager->action(Akonadi::StandardContactActionManager::CreateContact)->trigger();
 }
 
 void MainWidget::newGroup()
 {
-    mActionManager->action(ContactEditor::StandardContactActionManager::CreateContactGroup)->trigger();
+    mActionManager->action(Akonadi::StandardContactActionManager::CreateContactGroup)->trigger();
 }
 
 /**
@@ -1067,3 +1062,5 @@ void MainWidget::slotCurrentCollectionChanged(const Akonadi::Collection &col)
     bool isOnline;
     mServerSideSubscription->setEnabled(PimCommon::MailUtil::isImapFolder(col, isOnline));
 }
+
+#include "moc_mainwidget.cpp"
