@@ -25,13 +25,8 @@
 #include <QPointer>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/NotificationPopup>
 #include <KUserFeedbackQt6/Provider>
-#else
-#include <KUserFeedback/NotificationPopup>
-#include <KUserFeedback/Provider>
-#endif
 #endif
 
 MainWindow::MainWindow()
@@ -118,11 +113,11 @@ void MainWindow::updateHamburgerMenu()
     menu->addAction(actionCollection()->action(QStringLiteral("akonadi_resource_create")));
     menu->addSeparator();
 
-    menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Print))));
-    menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::PrintPreview))));
+    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Print)));
+    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::PrintPreview)));
     menu->addSeparator();
 
-    menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
+    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
     mHamburgerMenu->setMenu(menu);
 }
 
@@ -147,7 +142,7 @@ void MainWindow::configureKeyBindings()
 
 void MainWindow::configureToolbars()
 {
-    KConfigGroup grp = KSharedConfig::openConfig()->group("MainWindow");
+    KConfigGroup grp = KSharedConfig::openConfig()->group(QStringLiteral("MainWindow"));
     saveMainWindowSettings(grp);
 
     QPointer<KEditToolBar> dlg = new KEditToolBar(factory());
@@ -160,7 +155,7 @@ void MainWindow::newToolbarConfig()
 {
     createGUI(QStringLiteral("kaddressbookui.rc"));
 
-    applyMainWindowSettings(KSharedConfig::openConfig()->group("MainWindow"));
+    applyMainWindowSettings(KSharedConfig::openConfig()->group(QStringLiteral("MainWindow")));
 }
 
 void MainWindow::slotToggleMenubar(bool dontShowWarning)
@@ -183,3 +178,5 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
         Settings::self()->setShowMenuBar(mShowMenuBarAction->isChecked());
     }
 }
+
+#include "moc_mainwindow.cpp"
