@@ -29,7 +29,7 @@ static const char ContactHeaderForeColor[] = "ContactHeaderForeColor";
 static const char ContactHeaderBGColor[] = "ContactHeaderBGColor";
 
 struct ContactBlock {
-    using List = QVector<ContactBlock>;
+    using List = QList<ContactBlock>;
 
     QString header;
     QStringList entries;
@@ -231,7 +231,7 @@ DetailledPrintStyle::DetailledPrintStyle(PrintingWizard *parent)
 
     addPage(mPageAppearance, i18n("Detailed Print Style - Appearance"));
 
-    KConfigGroup config(KSharedConfig::openConfig(), ConfigSectionName);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(ConfigSectionName));
 
     mPageAppearance->kcbHeaderBGColor->setColor(config.readEntry(ContactHeaderBGColor, QColor(Qt::black)));
 
@@ -248,7 +248,7 @@ void DetailledPrintStyle::print(const KContacts::Addressee::List &contacts, Prin
     const QColor headerBackgroundColor = mPageAppearance->kcbHeaderBGColor->color();
     const QColor headerForegroundColor = mPageAppearance->kcbHeaderTextColor->color();
 
-    KConfigGroup config(KSharedConfig::openConfig(), ConfigSectionName);
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(ConfigSectionName));
     config.writeEntry(ContactHeaderForeColor, headerForegroundColor);
     config.writeEntry(ContactHeaderBGColor, headerBackgroundColor);
     config.sync();
@@ -287,3 +287,5 @@ QString DetailledPrintStyleFactory::description() const
 {
     return i18n("Detailed Style");
 }
+
+#include "moc_detailledstyle.cpp"
